==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/RectangularArrayFinder.h <==
// public class soot.jimple.toolkits.annotation.arraycheck.RectangularArrayFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 6a41f5ea6fee677e soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_soot_Local$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$addInfoFromMethod$144b58942fc73f29(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_soot_SootMethod$object *);
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$isRectangular$e070af4ec2a4e6b5(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$lookforPattern$2c2d4bcca1e0d919(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_object *, struct _jc_object *, jint, struct _jc_object *, struct _jc_soot_Type$object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$recoverRectArray$35fda013e688dc43(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_soot_SootMethod$object *);
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$transferPattern$8085c6902b5ca556(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_soot_Type$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$addInfoFromMethod$144b58942fc73f29;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$internalTransform$b44b61d0d9f22a06;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$isRectangular$e070af4ec2a4e6b5;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$lookforPattern$2c2d4bcca1e0d919;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$recoverRectArray$35fda013e688dc43;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$transferPattern$8085c6902b5ca556;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$v$4816acccbb6449f3(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vmethods {
	void	(*addInfoFromMethod$144b58942fc73f29)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_soot_SootMethod$object *);
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	jboolean	(*isRectangular$e070af4ec2a4e6b5)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_java_lang_Object$object *);
	jint	(*lookforPattern$2c2d4bcca1e0d919)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_object *, struct _jc_object *, jint, struct _jc_object *, struct _jc_soot_Type$object *, struct _jc_object_array *);
	void	(*recoverRectArray$35fda013e688dc43)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_soot_SootMethod$object *);
	void	(*transferPattern$8085c6902b5ca556)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_soot_Type$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vmethods	soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_refs {
	struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object	*agraph;
	struct _jc_object	*falseSet;
	struct _jc_object	*trueSet;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_refs	soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/RectangularArrayFinder.h <==
// public class soot.jimple.toolkits.annotation.arraycheck.RectangularArrayFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 6a41f5ea6fee677e soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_soot_Local$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$addInfoFromMethod$144b58942fc73f29(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$isRectangular$e070af4ec2a4e6b5(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$lookforPattern$2c2d4bcca1e0d919(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_object *, struct _jc_object *, jint, struct _jc_object *, struct _jc_soot_Type$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$recoverRectArray$35fda013e688dc43(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$transferPattern$8085c6902b5ca556(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_soot_Type$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$addInfoFromMethod$144b58942fc73f29;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$internalTransform$b44b61d0d9f22a06;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$isRectangular$e070af4ec2a4e6b5;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$lookforPattern$2c2d4bcca1e0d919;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$recoverRectArray$35fda013e688dc43;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method_info$transferPattern$8085c6902b5ca556;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$method$v$4816acccbb6449f3(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vmethods {
	void	(*addInfoFromMethod$144b58942fc73f29)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*isRectangular$e070af4ec2a4e6b5)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*lookforPattern$2c2d4bcca1e0d919)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_object *, struct _jc_object *, jint, struct _jc_object *, struct _jc_soot_Type$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	void	(*recoverRectArray$35fda013e688dc43)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	void	(*transferPattern$8085c6902b5ca556)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object *, struct _jc_object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_soot_Type$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vmethods	soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_refs {
	struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object	*agraph;
	struct _jc_object	*falseSet;
	struct _jc_object	*trueSet;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_refs	soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_RectangularArrayFinder_H_ */
